@@ -1,14 +1,13 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-08 11:55:54
-# @Last Modified time: 2020-08-11 19:17:52
+# @Last Modified time: 2021-02-08 13:49:08
 # @github: https://github.com/longfengpili
 
-#!/usr/bin/env python3
+# !/usr/bin/env python3
 # -*- coding:utf-8 -*-
 
 import os
-import pandas as pd
 import time
 
 from .base import DBbase
@@ -40,12 +39,11 @@ class DBFileExec(DBbase):
         dblogger.info(f"【Final Arguments】The file 【{filename}】 Use arguments {arguments}")
         for desc, sql in sqls.items():
             # dblogger.info(f"Start {desc}")
-            verbose = True if 'verbose' in desc or filename.startswith('test') \
-                        or filename.endswith('test.sql') else False
+            verbose = 1 if 'verbose1' in desc or filename.startswith('test') \
+                else 2 if 'verbose2' in desc else 0
             rows, action, result = self.execute(sql, verbose=verbose)
             results[desc] = result
             # dblogger.info(f"End {desc}")
         et = time.time()
         dblogger.info(f"End Job 【{filename}】, cost {et - st:.2f} seconds".center(80, '='))
         return results
-
